from splent_framework.blueprints.base_blueprint import BaseBlueprint

mail_bp = BaseBlueprint("mail", __name__, template_folder="templates")


from .services import MailService  # noqa: E402

mail_service = MailService()


def init_feature(app):
    mail_service.init_app(app)
    app.mail_service = mail_service


def inject_context_vars(app):
    return {}



import os

from flask_mail import Mail, Message
from splent_io.splent_feature_mail.repositories import MailRepository
from splent_framework.services.BaseService import BaseService


class MailService(BaseService):
    def __init__(self):
        super().__init__(MailRepository())
        self.mail = None
        self.sender = None

    def init_app(self, app):
        app.config["MAIL_SERVER"] = os.getenv("MAIL_SERVER", "smtp.office365.com")
        app.config["MAIL_PORT"] = int(os.getenv("MAIL_PORT", "587"))
        app.config["MAIL_USE_TLS"] = os.getenv("MAIL_USE_TLS", "True") == "True"
        app.config["MAIL_USE_SSL"] = os.getenv("MAIL_USE_SSL", "False") == "True"
        app.config["MAIL_USERNAME"] = os.getenv(
            "MAIL_USERNAME", "tu_correo@tudominio.com"
        )
        app.config["MAIL_PASSWORD"] = os.getenv("MAIL_PASSWORD", "tu_password")
        app.config["MAIL_DEFAULT_SENDER"] = os.getenv("MAIL_USERNAME")

        self.mail = Mail(app)
        self.sender = app.config["MAIL_USERNAME"]

    def send_email(self, subject, recipients, body, html_body=None):
        msg = Message(subject, sender=self.sender, recipients=recipients)
        msg.body = body
        if html_body:
            msg.html = html_body

        self.mail.send(msg)
